@@ -23,7 +23,7 @@ def _format_labels(y_list: List[int], label: int) -> List[int]:
 
 
 def _formula(cm: List[List[int]], cost_matrix: List[List[float]]) -> float:
-    score = np.dot(cm, cost_matrix).sum()
+    score = (cm * cost_matrix).sum()
 
     return score
 
@@ -48,7 +48,6 @@ def guap_metric(
         results[le.classes_[i]] = _formula(cm, cost_matrix)
     _tmp = sum(results.values())
     output = {"sum": sum(results.values()), "average": mean(results.values())}
-    print(output)
 
     return output
 
@@ -62,6 +61,5 @@ def binary_guap_metric(
     labels = le.transform(le.classes_)
     cm = guap_cm(y_true_encoded, y_pred_encoded)
     score = _formula(cm, cost_matrix)
-    print(score)
 
     return score
